@@ -1,9 +1,11 @@
 import math
 import random
 
-from eqsmart.main.consumer import Consumer, fail_server_list
+from eqsmart.main.consumer import Consumer
 from eqlink.components.remote_server import remote_server
+from eqlink.main.clent import fail_server_list
 import json
+import traceback
 
 protocol = {
     'type': 'call provider',
@@ -26,9 +28,11 @@ class RemoteCall:
         service_path = self.service_path.split('/')
         protocol['service_name'] = service_path[:-1]
         protocol['func'] = service_path[-1]
+        ''' 远程服务列表 '''
         provider_service_list = remote_server.__get__()
+        ''' 远程服务地址信息'''
         provider_server = provider_service_list[service_path[0]]['remote']
-        # TODO 增加服务调用权重控制
+        ''' 远程服务加权调用：计算权重 '''
         weight_check = {}
         count_w = 0  # 用于远程服务遍历的计数器
         count_c = 0  # 权值和
@@ -40,7 +44,7 @@ class RemoteCall:
         weight_m = 0  # 中间值
         call_random = random.randint(0, 100)  # 随机数
         call_weight = 0  # 加权计算后，被调用的远程服务
-        print('[eqsmart] [加权调用]', weight_check)
+        print('[eqsmart] 远程服务加权调用，服务权重:', weight_check)
         for item in weight_check.keys():
             c_weight = int(weight_check[item]) * weight_factor
             weight_check[item] = [weight_m, weight_m + c_weight]
@@ -50,12 +54,9 @@ class RemoteCall:
         print('[eqsmart] [加权调用]', call_weight, call_random)
         '''以上为加权调用的权重计算'''
         provider_conf = {
-            # 远程服务器地址
-            'IP': provider_server[call_weight]['ip'],
-            # 远程服务器端口
-            'PORT': provider_server[call_weight]['port'],
-            # 消息读取长度
-            'BUF_SIZE': 1024
+            'IP': provider_server[call_weight]['ip'],  # 远程服务器地址
+            'PORT': provider_server[call_weight]['port'],  # 远程服务器端口
+            'BUF_SIZE': 4096  # 消息读取长度
         }
         print('[eqsmart] 远程调用', provider_conf, protocol)
         try:
@@ -63,4 +64,6 @@ class RemoteCall:
         except Exception as e:
             fail_server_list.append({'IP': provider_conf['IP'], 'PORT': provider_conf['PORT']})
             print('[eqsmart] 远程调用失败！', e)
+            remote_call = json.dumps({'code': 'error', 'message': str(e)})
+            print(traceback.format_exc())
         return json.loads(remote_call)
